@@ -409,7 +409,8 @@ _eef_inst_func_dad (eef_addr_t opnd_addr, gchar sec)
   h_data = eef_regpair_get ('H');
   sec_data = eef_join16 (*dst_h, *dst_l);
 
-  _eef_flag_check_and_set_c (h_data, sec_data, '+');
+  /* check for overflow and (re)set carry flag */
+  sys.flag.c = ( ( (int)h_data + (int)sec_data ) >= (1<<16) );
 
   eef_regpair_put ('H', h_data + sec_data);
 
@@ -939,7 +940,8 @@ _eef_inst_func_39 (eef_addr_t opnd_addr)
   eef_data_t high;
 
   low = sys.reg.a & 0x0F;
-
+  high = sys.reg.a >> 4;
+  
   if (low > 9 || sys.flag.ac)
 	{
 	  sys.reg.a += 6;
@@ -948,7 +950,7 @@ _eef_inst_func_39 (eef_addr_t opnd_addr)
 	  else 
 		sys.flag.ac = 0;
 	}
-  high = sys.reg.a >> 4;
+
   if (high > 9 || sys.flag.c)
 	{
 	  sys.reg.a += (6 << 4);
