@@ -203,7 +203,9 @@ asm_listing_generate (AsmSource * src)
   /* get max len */
   max_len = asm_listing_binary_array_max_len (bin);
 	
-  listing = g_string_new (_(";Assembler generated listing. Do not hand edit and assemble\n"));
+  listing = g_string_new("");
+  g_string_append (listing, _("; Assembler generated listing; Not editable.\n"));
+  g_string_append_printf (listing, _("; Generated by GNUSim8085: %s\n"), PACKAGE_URL);
 	
   while ( bin[i] )
 	{
