@@ -343,7 +343,19 @@ asm_util_parse_number (gchar * str, gint * value)
 
 	  return asm_util_str_to_int (str, value, 16);
 	}
+  if (str[strlen (str) -1] == 'b' || str[strlen (str) - 1] == 'B')
+  	{
+  	  str[strlen (str) - 1] = '\0';
+  	  
+  	  return asm_util_str_to_int (str,value, 2);
+  	}
+  if (str[strlen (str) - 1] == 'o' || str[strlen (str) - 1] == 'O')
+	{
+	  str[strlen (str) - 1] = '\0';
 
+	  return asm_util_str_to_int (str, value, 8);
+	}
+  
   return asm_util_str_to_int (str, value, 10);
 }
 
@@ -405,7 +417,7 @@ asm_source_entry_parse_not_operand_but_this (AsmSourceEntry * entry,
 		  if (entry)
 			{
 			  asm_err_comm_send (entry->
-								 listing_buffer_line_no,
+								 listing_buffer_line_no+1,
 								 _("Expression error in symbol"),
 								 ASM_ERR_ERROR);
 			}
@@ -419,7 +431,7 @@ asm_source_entry_parse_not_operand_but_this (AsmSourceEntry * entry,
 		  if (entry)
 			{
 			  asm_err_comm_send (entry->
-								 listing_buffer_line_no,
+								 listing_buffer_line_no+1,
 								 _("Undefined symbol"),
 								 ASM_ERR_ERROR);
 			}
