@@ -44,8 +44,12 @@ gboolean
 on_window_main_delete_event (GtkWidget * widget,
 							 GdkEvent * event, gpointer user_data)
 {
+  if (gtk_text_buffer_get_modified ((GtkTextBuffer *)app->editor->buffer))
+	{
+	  if (!file_op_confirm_save())
+		return TRUE;
+	}
   gui_app_destroy ();
-
   return FALSE;
 }
 
@@ -114,9 +118,22 @@ on_save_as1_activate (GtkMenuItem * menuitem, gpointer user_data)
 }
 
 
+void
+on_print_activate (GtkAction * menuitem, gpointer user_data)
+{
+  g_assert (app->editor);
+  gui_editor_print (app->editor);
+}
+
+
 void
 on_quit1_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
+  if (gtk_text_buffer_get_modified ((GtkTextBuffer *)app->editor->buffer))
+	{
+	  if (!file_op_confirm_save())
+		return;
+	}
   gtk_main_quit ();
 }
 
@@ -310,7 +327,7 @@ on_8085_manual1_activate (GtkMenuItem * menuitem, gpointer user_data)
 
 
 void
-on_assembler_reference1_activate (GtkMenuItem * menuitem, gpointer user_data)
+on_assembler_tutorial1_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
   gtk_widget_show (create_window_start ());
 }
@@ -324,6 +341,17 @@ on_about1_activate (GtkMenuItem * menuitem, gpointer user_data)
 }
 
 
+void
+show_hide_side_pane (GtkToggleAction * menuitem, gpointer user_data)
+{
+  GtkWidget *side_pane;
+  side_pane = lookup_widget (app->window_main, "main_vpaned_data");
+  if (gtk_toggle_action_get_active (menuitem))
+	  gtk_widget_hide (side_pane);
+  else
+	  gtk_widget_show (side_pane);
+}
+
 
 void
 on_main_io_set_clicked (GtkButton * button, gpointer user_data)
@@ -435,6 +463,7 @@ on_show_listing1_activate (GtkMenuItem * menuitem, gpointer user_data)
   g_assert (edit);
   gui_editor_show (edit);
   gui_editor_set_text (edit, list->str);
+  gui_editor_set_readonly (edit, TRUE);
   gtk_box_pack_end_defaults (GTK_BOX (cont), edit->scroll);
   gtk_window_maximize (GTK_WINDOW (wind));
   gtk_widget_show_all (wind);
@@ -455,6 +484,13 @@ on_listing_save_clicked (GtkButton * button, gpointer user_data)
   file_op_listing_save (ltext);
 }
 
+void
+on_listing_print_clicked (GtkButton * button, gpointer user_data)
+{
+  g_assert (edit);
+  gui_editor_print (edit);
+}
+
 void
 on_main_but_to_hex_clicked (GtkButton * button, gpointer user_data)
 {
