@@ -69,9 +69,9 @@ cb_clicked (GtkTreeView * listview, gpointer user_data)
   if (ln == 0)
 	return;
 
-  /* FIXME line number is not correct some times at which ln-1 will work */
-  gui_editor_goto_line (app->editor, ln /* -1 ? */);
   gtk_widget_grab_focus (app->editor->widget);
+  gui_editor_goto_line (app->editor, ln-1);
+
 }
 
 static void
@@ -102,7 +102,7 @@ gui_list_message_attach_me (void)
 {
   GtkWidget *cont;
 
-  cont = lookup_widget (app->window_main, "main_vpaned_msg");
+  cont = lookup_widget (app->window_main, "main_vpaned_data");
   g_assert (cont);
 
   create_me ();
